# haico: human–AI collaboration 

This repository contains the official implementation of [Confidence-weighted integration of human and machine judgments for superior decision-making](https://www.cell.com/patterns/fulltext/S2666-3899(25)00271-5), part of the [BrainGPT project](https://braingpt.org/).

## Usage
To run the code, you need to clone and install this repository locally, e.g., in the command line, run: 
```shell
git clone https://github.com/braingpt-lovelab/haico.git
cd haico
pip install -e .
```

## Attribution
If you use `haico` consider citing our manuscript.
```
@article{YanezEtAl2026,
  author    = {Y{\'a}{\~n}ez, Felipe and Luo, Xiaoliang and Valerio Minero, Omar and Love, Bradley C.},
  title     = {Confidence-weighted integration of human and machine judgments for superior decision-making},
  journal   = {Patterns},
  year      = {2026},
  volume    = {7},
  number    = {2},
  publisher = {Elsevier},
  issn      = {2666-3899},
  doi       = {10.1016/j.patter.2025.101423},
  url       = {https://doi.org/10.1016/j.patter.2025.101423}
}
```
